/*
 * Copyright (c) 2007 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: WSIFTestCase.java,v 1.3 2007/03/23 16:20:32 aslom Exp $
 */
package edu.indiana.extreme.xbaya.test;

import junit.framework.TestSuite;
import xsul5.MLogger;
import edu.indiana.extreme.xbaya.XBayaConstants;
import edu.indiana.extreme.xbaya.component.gui.ComponentTreeNode;
import edu.indiana.extreme.xbaya.rescat.ResourceCatalogClient;
import edu.indiana.extreme.xbaya.xregistry.XRegistry;

/**
 * @author Satoshi Shirasuna
 */
public class WSIFTestCase extends XBayaTestCase {

    private static final MLogger logger = MLogger.getLogger();

    private ComponentTreeNode resouceCatalogComponentTree;

    private ComponentTreeNode xRegistryComponentTree;

    /**
     * @param args
     */
    public static void main(String[] args) {
        junit.textui.TestRunner.run(new TestSuite(WSIFTestCase.class));
    }

    /**
     * @see edu.indiana.extreme.xbaya.test.XBayaTestCase#setUp()
     */
    @Override
    protected void setUp() throws Exception {
        super.setUp();
        this.resouceCatalogComponentTree = null;
        this.xRegistryComponentTree = null;
    }

    /**
     * @throws InterruptedException
     */
    public void ttestResourceCatalog() throws InterruptedException {

        Thread resourceCatalogThread = new Thread() {
            @Override
            public void run() {
                try {
                    ResourceCatalogClient client = new ResourceCatalogClient(
                            XBayaConstants.DEFAULT_RESOURCE_CATALOG_URL);
                    WSIFTestCase.this.resouceCatalogComponentTree = client
                            .getComponentTree();
                } catch (Exception e) {
                    logger.caught(e);
                }
            }
        };

        resourceCatalogThread.start();

        // Join them otherwise the test finishes.
        resourceCatalogThread.join();

        assertNotNull(this.resouceCatalogComponentTree);
    }

    /**
     * @throws InterruptedException
     */
    public void ttestXRegistry() throws InterruptedException {
        Thread xRegistryThread = new Thread() {
            @Override
            public void run() {
                try {
                    XRegistry client = new XRegistry(
                            XBayaConstants.DEFAULT_XREGISTRY_URL,
                            XRegistry.Type.ABSTRACT);
                    WSIFTestCase.this.xRegistryComponentTree = client
                            .getComponentTree();
                } catch (Exception e) {
                    logger.caught(e);
                }
            }
        };

        xRegistryThread.start();

        // Join them otherwise the test finishes.
        xRegistryThread.join();

        assertNotNull(this.xRegistryComponentTree);
    }

    /**
     * @throws InterruptedException
     */
    public void testSynchronization() throws InterruptedException {

        Thread resourceCatalogThread = new Thread() {
            @Override
            public void run() {
                try {
                    ResourceCatalogClient client = new ResourceCatalogClient(
                            XBayaConstants.DEFAULT_RESOURCE_CATALOG_URL);
                    WSIFTestCase.this.resouceCatalogComponentTree = client
                            .getComponentTree();
                    System.err.println("ALEK r="+WSIFTestCase.this.resouceCatalogComponentTree);
                } catch (Exception e) {
                    logger.caught(e);
                }
            }
        };

        Thread xRegistryThread = new Thread() {
            @Override
            public void run() {
                try {
                    XRegistry client = new XRegistry(
                            XBayaConstants.DEFAULT_XREGISTRY_URL,
                            XRegistry.Type.ABSTRACT);
                    WSIFTestCase.this.xRegistryComponentTree = client
                            .getComponentTree();
                    System.err.println("ALEK c="+WSIFTestCase.this.xRegistryComponentTree);
                } catch (Exception e) {
                    logger.caught(e);
                }
            }
        };

        resourceCatalogThread.start();
        xRegistryThread.start();

        System.err.println("ALEK2 c="+WSIFTestCase.this.xRegistryComponentTree);
        System.err.println("ALEK2 r="+WSIFTestCase.this.resouceCatalogComponentTree);

        // Join them otherwise the test finishes.
        resourceCatalogThread.join();
        xRegistryThread.join();

        System.err.println("ALEK3 c="+WSIFTestCase.this.xRegistryComponentTree);
        System.err.println("ALEK3 r="+WSIFTestCase.this.resouceCatalogComponentTree);

        assertNotNull(this.resouceCatalogComponentTree);
        assertNotNull(this.xRegistryComponentTree);
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 *
 * Copyright (c) 2007 The Trustees of Indiana University. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 *
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 *
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 *
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 *
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 *
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 *
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 *
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 *
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
